@@ -9,7 +9,3 @@ DISABLE_AUTODISCOVER = getattr(settings, 'SITEPREFS_DISABLE_AUTODISCOVER', False
 
 PREFS_MODULE_NAME = getattr(settings, 'SITEPREFS_MODULE_NAME', 'settings')
 """Module name used by siteprefs.toolbox.autodiscover_siteprefs() to find preferences in application packages."""
-
-MANAGE_SAFE_COMMANDS = getattr(
-    settings, 'SITEPREFS_MANAGE_SAFE_COMMANDS', ['runserver', 'runserver_plus', 'run_gunicorn', 'celeryd'])
-"""List of commands called by manage.py where autodiscover is enabled"""
